"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetCoursesRequest(object):
    """Implementation of the 'GetCoursesRequest' model.

    This is the request class for the get courses API

    Attributes:
        location_i_ds (List[int]): Return only courses that are available for the
            specified LocationIds.
        course_i_ds (List[int]): Return only courses that are available for the
            specified CourseIds.
        staff_i_ds (List[int]): Return only courses that are available for the
            specified StaffIds.
        program_i_ds (List[int]): Return only courses that are available for the
            specified ProgramIds.
        start_date (datetime): The start date range. Any active courses that are on
            or after this day.  <br />(optional) Defaults to today.
        end_date (datetime): The end date range. Any active courses that are on or
            before this day.  <br />(optional) Defaults to StartDate.
        semester_i_ds (List[int]): Return only courses that are available for the
            specified SemesterIds.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "location_i_ds": "LocationIDs",
        "course_i_ds": "CourseIDs",
        "staff_i_ds": "StaffIDs",
        "program_i_ds": "ProgramIDs",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "semester_i_ds": "SemesterIDs",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "location_i_ds",
        "course_i_ds",
        "staff_i_ds",
        "program_i_ds",
        "start_date",
        "end_date",
        "semester_i_ds",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        location_i_ds=APIHelper.SKIP,
        course_i_ds=APIHelper.SKIP,
        staff_i_ds=APIHelper.SKIP,
        program_i_ds=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        semester_i_ds=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetCoursesRequest instance."""
        # Initialize members of the class
        if location_i_ds is not APIHelper.SKIP:
            self.location_i_ds = location_i_ds
        if course_i_ds is not APIHelper.SKIP:
            self.course_i_ds = course_i_ds
        if staff_i_ds is not APIHelper.SKIP:
            self.staff_i_ds = staff_i_ds
        if program_i_ds is not APIHelper.SKIP:
            self.program_i_ds = program_i_ds
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if semester_i_ds is not APIHelper.SKIP:
            self.semester_i_ds = semester_i_ds
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        location_i_ds =\
            dictionary.get("LocationIDs")\
            if dictionary.get("LocationIDs")\
                else APIHelper.SKIP
        course_i_ds =\
            dictionary.get("CourseIDs")\
            if dictionary.get("CourseIDs")\
                else APIHelper.SKIP
        staff_i_ds =\
            dictionary.get("StaffIDs")\
            if dictionary.get("StaffIDs")\
                else APIHelper.SKIP
        program_i_ds =\
            dictionary.get("ProgramIDs")\
            if dictionary.get("ProgramIDs")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        semester_i_ds =\
            dictionary.get("SemesterIDs")\
            if dictionary.get("SemesterIDs")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(location_i_ds,
                   course_i_ds,
                   staff_i_ds,
                   program_i_ds,
                   start_date,
                   end_date,
                   semester_i_ds,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _location_i_ds=(
            self.location_i_ds
            if hasattr(self, "location_i_ds")
            else None
        )
        _course_i_ds=(
            self.course_i_ds
            if hasattr(self, "course_i_ds")
            else None
        )
        _staff_i_ds=(
            self.staff_i_ds
            if hasattr(self, "staff_i_ds")
            else None
        )
        _program_i_ds=(
            self.program_i_ds
            if hasattr(self, "program_i_ds")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _semester_i_ds=(
            self.semester_i_ds
            if hasattr(self, "semester_i_ds")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"location_i_ds={_location_i_ds!r}, "
            f"course_i_ds={_course_i_ds!r}, "
            f"staff_i_ds={_staff_i_ds!r}, "
            f"program_i_ds={_program_i_ds!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"semester_i_ds={_semester_i_ds!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _location_i_ds=(
            self.location_i_ds
            if hasattr(self, "location_i_ds")
            else None
        )
        _course_i_ds=(
            self.course_i_ds
            if hasattr(self, "course_i_ds")
            else None
        )
        _staff_i_ds=(
            self.staff_i_ds
            if hasattr(self, "staff_i_ds")
            else None
        )
        _program_i_ds=(
            self.program_i_ds
            if hasattr(self, "program_i_ds")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _semester_i_ds=(
            self.semester_i_ds
            if hasattr(self, "semester_i_ds")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"location_i_ds={_location_i_ds!s}, "
            f"course_i_ds={_course_i_ds!s}, "
            f"staff_i_ds={_staff_i_ds!s}, "
            f"program_i_ds={_program_i_ds!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"semester_i_ds={_semester_i_ds!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ContractItem(object):
    """Implementation of the 'ContractItem' model.

    Attributes:
        id (str): The ID of the item.
        name (str): The name of the item.
        description (str): A description of the item.
        mtype (str): The type of the item.
        price (float): The price of the item.
        quantity (int): The quantity of the item.
        one_time_item (bool): When `true`, indicates that the item is charged only
            once.<br />  When `false`, indicates that the item is charged multiple
            times.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "description": "Description",
        "mtype": "Type",
        "price": "Price",
        "quantity": "Quantity",
        "one_time_item": "OneTimeItem",
    }

    _optionals = [
        "id",
        "name",
        "description",
        "mtype",
        "price",
        "quantity",
        "one_time_item",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        description=APIHelper.SKIP,
        mtype=APIHelper.SKIP,
        price=APIHelper.SKIP,
        quantity=APIHelper.SKIP,
        one_time_item=APIHelper.SKIP):
        """Initialize a ContractItem instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if description is not APIHelper.SKIP:
            self.description = description
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype
        if price is not APIHelper.SKIP:
            self.price = price
        if quantity is not APIHelper.SKIP:
            self.quantity = quantity
        if one_time_item is not APIHelper.SKIP:
            self.one_time_item = one_time_item

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        mtype =\
            dictionary.get("Type")\
            if dictionary.get("Type")\
                else APIHelper.SKIP
        price =\
            dictionary.get("Price")\
            if dictionary.get("Price")\
                else APIHelper.SKIP
        quantity =\
            dictionary.get("Quantity")\
            if dictionary.get("Quantity")\
                else APIHelper.SKIP
        one_time_item =\
            dictionary.get("OneTimeItem")\
            if "OneTimeItem" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   description,
                   mtype,
                   price,
                   quantity,
                   one_time_item)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        _one_time_item=(
            self.one_time_item
            if hasattr(self, "one_time_item")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"description={_description!r}, "
            f"mtype={_mtype!r}, "
            f"price={_price!r}, "
            f"quantity={_quantity!r}, "
            f"one_time_item={_one_time_item!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _mtype=(
            self.mtype
            if hasattr(self, "mtype")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        _one_time_item=(
            self.one_time_item
            if hasattr(self, "one_time_item")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"description={_description!s}, "
            f"mtype={_mtype!s}, "
            f"price={_price!s}, "
            f"quantity={_quantity!s}, "
            f"one_time_item={_one_time_item!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.purchased_item import (
    PurchasedItem,
)
from mindbodypublicapi.models.sale_payment import (
    SalePayment,
)


class Sale(object):
    """Implementation of the 'Sale' model.

    Contains the Sale details.

    Attributes:
        id (int): The sale ID.
        sale_date (datetime): The date the item was sold.
        sale_time (str): The time the item was sold.
        sale_date_time (datetime): The date and time the item was sold.
        original_sale_date_time (datetime): The date and time the item was sold
            originally.
        sales_rep_id (int): The sales representative ID
        client_id (str): The ID of the client who made the purchase.
        recipient_client_id (int): Recipient Client Id
        purchased_items (List[PurchasedItem]): Contains the `PurchasedItem` objects
            that describe the purchased items.
        location_id (int): The ID of the location where the sale takes place.
        payments (List[SalePayment]): Contains the `SalePayment` objects that
            describe the payments that contributed to this sale.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "sale_date": "SaleDate",
        "sale_time": "SaleTime",
        "sale_date_time": "SaleDateTime",
        "original_sale_date_time": "OriginalSaleDateTime",
        "sales_rep_id": "SalesRepId",
        "client_id": "ClientId",
        "recipient_client_id": "RecipientClientId",
        "purchased_items": "PurchasedItems",
        "location_id": "LocationId",
        "payments": "Payments",
    }

    _optionals = [
        "id",
        "sale_date",
        "sale_time",
        "sale_date_time",
        "original_sale_date_time",
        "sales_rep_id",
        "client_id",
        "recipient_client_id",
        "purchased_items",
        "location_id",
        "payments",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        sale_date=APIHelper.SKIP,
        sale_time=APIHelper.SKIP,
        sale_date_time=APIHelper.SKIP,
        original_sale_date_time=APIHelper.SKIP,
        sales_rep_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        recipient_client_id=APIHelper.SKIP,
        purchased_items=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        payments=APIHelper.SKIP):
        """Initialize a Sale instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if sale_date is not APIHelper.SKIP:
            self.sale_date =\
                 APIHelper.apply_datetime_converter(
                sale_date, APIHelper.RFC3339DateTime)\
                 if sale_date else None
        if sale_time is not APIHelper.SKIP:
            self.sale_time = sale_time
        if sale_date_time is not APIHelper.SKIP:
            self.sale_date_time =\
                 APIHelper.apply_datetime_converter(
                sale_date_time, APIHelper.RFC3339DateTime)\
                 if sale_date_time else None
        if original_sale_date_time is not APIHelper.SKIP:
            self.original_sale_date_time =\
                 APIHelper.apply_datetime_converter(
                original_sale_date_time, APIHelper.RFC3339DateTime)\
                 if original_sale_date_time else None
        if sales_rep_id is not APIHelper.SKIP:
            self.sales_rep_id = sales_rep_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if recipient_client_id is not APIHelper.SKIP:
            self.recipient_client_id = recipient_client_id
        if purchased_items is not APIHelper.SKIP:
            self.purchased_items = purchased_items
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if payments is not APIHelper.SKIP:
            self.payments = payments

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        sale_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("SaleDate")).datetime\
            if dictionary.get("SaleDate") else APIHelper.SKIP
        sale_time =\
            dictionary.get("SaleTime")\
            if dictionary.get("SaleTime")\
                else APIHelper.SKIP
        sale_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("SaleDateTime")).datetime\
            if dictionary.get("SaleDateTime") else APIHelper.SKIP
        original_sale_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("OriginalSaleDateTime")).datetime\
            if dictionary.get("OriginalSaleDateTime") else APIHelper.SKIP
        sales_rep_id =\
            dictionary.get("SalesRepId")\
            if dictionary.get("SalesRepId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        recipient_client_id =\
            dictionary.get("RecipientClientId")\
            if dictionary.get("RecipientClientId")\
                else APIHelper.SKIP
        purchased_items = None
        if dictionary.get("PurchasedItems") is not None:
            purchased_items = [
                PurchasedItem.from_dictionary(x)
                    for x in dictionary.get("PurchasedItems")
            ]
        else:
            purchased_items = APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        payments = None
        if dictionary.get("Payments") is not None:
            payments = [
                SalePayment.from_dictionary(x)
                    for x in dictionary.get("Payments")
            ]
        else:
            payments = APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   sale_date,
                   sale_time,
                   sale_date_time,
                   original_sale_date_time,
                   sales_rep_id,
                   client_id,
                   recipient_client_id,
                   purchased_items,
                   location_id,
                   payments)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _sale_date=(
            self.sale_date
            if hasattr(self, "sale_date")
            else None
        )
        _sale_time=(
            self.sale_time
            if hasattr(self, "sale_time")
            else None
        )
        _sale_date_time=(
            self.sale_date_time
            if hasattr(self, "sale_date_time")
            else None
        )
        _original_sale_date_time=(
            self.original_sale_date_time
            if hasattr(self, "original_sale_date_time")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _recipient_client_id=(
            self.recipient_client_id
            if hasattr(self, "recipient_client_id")
            else None
        )
        _purchased_items=(
            self.purchased_items
            if hasattr(self, "purchased_items")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _payments=(
            self.payments
            if hasattr(self, "payments")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"sale_date={_sale_date!r}, "
            f"sale_time={_sale_time!r}, "
            f"sale_date_time={_sale_date_time!r}, "
            f"original_sale_date_time={_original_sale_date_time!r}, "
            f"sales_rep_id={_sales_rep_id!r}, "
            f"client_id={_client_id!r}, "
            f"recipient_client_id={_recipient_client_id!r}, "
            f"purchased_items={_purchased_items!r}, "
            f"location_id={_location_id!r}, "
            f"payments={_payments!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _sale_date=(
            self.sale_date
            if hasattr(self, "sale_date")
            else None
        )
        _sale_time=(
            self.sale_time
            if hasattr(self, "sale_time")
            else None
        )
        _sale_date_time=(
            self.sale_date_time
            if hasattr(self, "sale_date_time")
            else None
        )
        _original_sale_date_time=(
            self.original_sale_date_time
            if hasattr(self, "original_sale_date_time")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _recipient_client_id=(
            self.recipient_client_id
            if hasattr(self, "recipient_client_id")
            else None
        )
        _purchased_items=(
            self.purchased_items
            if hasattr(self, "purchased_items")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _payments=(
            self.payments
            if hasattr(self, "payments")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"sale_date={_sale_date!s}, "
            f"sale_time={_sale_time!s}, "
            f"sale_date_time={_sale_date_time!s}, "
            f"original_sale_date_time={_original_sale_date_time!s}, "
            f"sales_rep_id={_sales_rep_id!s}, "
            f"client_id={_client_id!s}, "
            f"recipient_client_id={_recipient_client_id!s}, "
            f"purchased_items={_purchased_items!s}, "
            f"location_id={_location_id!s}, "
            f"payments={_payments!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501

class PaymentMethodEnum(object):
    """Implementation of the 'PaymentMethod' enum.

    The payment method.

    Attributes:
        OTHER: The enum member of type str.
        CREDITCARD: The enum member of type str.
        DEBITACCOUNT: The enum member of type str.
        ACH: The enum member of type str.

    """

    OTHER = "Other"

    CREDITCARD = "CreditCard"

    DEBITACCOUNT = "DebitAccount"

    ACH = "ACH"

    @classmethod
    def from_value(cls, value, default=None):
        """Return the matching enum value for the given input."""
        if value is None:
            return default

        # If numeric and matches directly
        if isinstance(value, int):
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and val == value:
                    return val

        # If string, perform case-insensitive match
        if isinstance(value, str):
            value_lower = value.lower()
            for name, val in cls.__dict__.items():
                if not name.startswith("_") and (
                    name.lower() == value_lower or str(val).lower() == value_lower
                ):
                    return val

        # Fallback to default
        return default



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class SuspendContractRequest(object):
    """Implementation of the 'SuspendContractRequest' model.

    Attributes:
        client_id (str): The ID of the client.
        client_contract_id (int): The unique ID of the sale of the contract.
        suspension_type (str): ex. Illness, Injury, Vacation. (Note this can be
            customized by each studio).  If provided, then Duration, DurationUnit,
            and SuspensionFee (if applicable) are automatically applied. Restrict
            Days are not supported.
        suspension_start (datetime): The contract suspension start date.  Default:
            *today’s date*
        duration (int): The number of (DurationUnit) the suspension lasts.
        duration_unit (int): The unit applied to Duration.
        open_ended (bool): When `true`, indicates that suspension is open ended.
            Also, when `true`, then Duration and DurationUnit are ignored.  Default:
            *false*
        suspension_notes (str): The comments for suspending a contract.
        suspension_fee (float): An optional charge that clients who wish to pause a
            contract for a set period of time can be charged.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "client_contract_id": "ClientContractId",
        "suspension_type": "SuspensionType",
        "suspension_start": "SuspensionStart",
        "duration": "Duration",
        "duration_unit": "DurationUnit",
        "open_ended": "OpenEnded",
        "suspension_notes": "SuspensionNotes",
        "suspension_fee": "SuspensionFee",
    }

    _optionals = [
        "suspension_type",
        "suspension_start",
        "duration",
        "duration_unit",
        "open_ended",
        "suspension_notes",
        "suspension_fee",
    ]

    def __init__(
        self,
        client_id=None,
        client_contract_id=None,
        suspension_type=APIHelper.SKIP,
        suspension_start=APIHelper.SKIP,
        duration=APIHelper.SKIP,
        duration_unit=APIHelper.SKIP,
        open_ended=APIHelper.SKIP,
        suspension_notes=APIHelper.SKIP,
        suspension_fee=APIHelper.SKIP):
        """Initialize a SuspendContractRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.client_contract_id = client_contract_id
        if suspension_type is not APIHelper.SKIP:
            self.suspension_type = suspension_type
        if suspension_start is not APIHelper.SKIP:
            self.suspension_start =\
                 APIHelper.apply_datetime_converter(
                suspension_start, APIHelper.RFC3339DateTime)\
                 if suspension_start else None
        if duration is not APIHelper.SKIP:
            self.duration = duration
        if duration_unit is not APIHelper.SKIP:
            self.duration_unit = duration_unit
        if open_ended is not APIHelper.SKIP:
            self.open_ended = open_ended
        if suspension_notes is not APIHelper.SKIP:
            self.suspension_notes = suspension_notes
        if suspension_fee is not APIHelper.SKIP:
            self.suspension_fee = suspension_fee

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        client_contract_id =\
            dictionary.get("ClientContractId")\
            if dictionary.get("ClientContractId")\
                else None
        suspension_type =\
            dictionary.get("SuspensionType")\
            if dictionary.get("SuspensionType")\
                else APIHelper.SKIP
        suspension_start = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("SuspensionStart")).datetime\
            if dictionary.get("SuspensionStart") else APIHelper.SKIP
        duration =\
            dictionary.get("Duration")\
            if dictionary.get("Duration")\
                else APIHelper.SKIP
        duration_unit =\
            dictionary.get("DurationUnit")\
            if dictionary.get("DurationUnit")\
                else APIHelper.SKIP
        open_ended =\
            dictionary.get("OpenEnded")\
            if "OpenEnded" in dictionary.keys()\
                else APIHelper.SKIP
        suspension_notes =\
            dictionary.get("SuspensionNotes")\
            if dictionary.get("SuspensionNotes")\
                else APIHelper.SKIP
        suspension_fee =\
            dictionary.get("SuspensionFee")\
            if dictionary.get("SuspensionFee")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   client_contract_id,
                   suspension_type,
                   suspension_start,
                   duration,
                   duration_unit,
                   open_ended,
                   suspension_notes,
                   suspension_fee)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _client_contract_id=self.client_contract_id
        _suspension_type=(
            self.suspension_type
            if hasattr(self, "suspension_type")
            else None
        )
        _suspension_start=(
            self.suspension_start
            if hasattr(self, "suspension_start")
            else None
        )
        _duration=(
            self.duration
            if hasattr(self, "duration")
            else None
        )
        _duration_unit=(
            self.duration_unit
            if hasattr(self, "duration_unit")
            else None
        )
        _open_ended=(
            self.open_ended
            if hasattr(self, "open_ended")
            else None
        )
        _suspension_notes=(
            self.suspension_notes
            if hasattr(self, "suspension_notes")
            else None
        )
        _suspension_fee=(
            self.suspension_fee
            if hasattr(self, "suspension_fee")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"client_contract_id={_client_contract_id!r}, "
            f"suspension_type={_suspension_type!r}, "
            f"suspension_start={_suspension_start!r}, "
            f"duration={_duration!r}, "
            f"duration_unit={_duration_unit!r}, "
            f"open_ended={_open_ended!r}, "
            f"suspension_notes={_suspension_notes!r}, "
            f"suspension_fee={_suspension_fee!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _client_contract_id=self.client_contract_id
        _suspension_type=(
            self.suspension_type
            if hasattr(self, "suspension_type")
            else None
        )
        _suspension_start=(
            self.suspension_start
            if hasattr(self, "suspension_start")
            else None
        )
        _duration=(
            self.duration
            if hasattr(self, "duration")
            else None
        )
        _duration_unit=(
            self.duration_unit
            if hasattr(self, "duration_unit")
            else None
        )
        _open_ended=(
            self.open_ended
            if hasattr(self, "open_ended")
            else None
        )
        _suspension_notes=(
            self.suspension_notes
            if hasattr(self, "suspension_notes")
            else None
        )
        _suspension_fee=(
            self.suspension_fee
            if hasattr(self, "suspension_fee")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"client_contract_id={_client_contract_id!s}, "
            f"suspension_type={_suspension_type!s}, "
            f"suspension_start={_suspension_start!s}, "
            f"duration={_duration!s}, "
            f"duration_unit={_duration_unit!s}, "
            f"open_ended={_open_ended!s}, "
            f"suspension_notes={_suspension_notes!s}, "
            f"suspension_fee={_suspension_fee!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetStaffImageURLRequest(object):
    """Implementation of the 'GetStaffImageURLRequest' model.

    This is the request class for the get staff image URL API

    Attributes:
        staff_id (int): The ID of the staff member whose image URL details you want
            to retrieve.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
    }

    _optionals = [
        "staff_id",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP):
        """Initialize a GetStaffImageURLRequest instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.checkout_payment_info import (
    CheckoutPaymentInfo,
)


class PurchaseAccountCreditRequest(object):
    """Implementation of the 'PurchaseAccountCreditRequest' model.

    Attributes:
        test (bool): When `true`, allows you to test the request without affecting
            the database.  When `false`, the request is carried out and the database
            is affected.
        location_id (int): The ID of the location where the account credit is being
            sold.
        client_id (str): The ID of the location where the account credit is being
            sold.
        send_email_receipt (bool): When `true`, indicates that a purchase receipt
            email should be sent to the purchasing client, if all settings are
            correctly configured.<br />  When `false`, no email is sent to the
            purchaser.
        sales_rep_id (int): The ID of the staff member to be marked as the sales rep
            for this account credit sale.
        consumer_present (bool): When `true`, indicates that the consumer is present
            or otherwise able to successfully negotiate an SCA challenge.   It is not
            a good idea to have this always be false as that could very likely lead
            to a bank declining all transactions for the merchant. Defaults to false.
            Default: **false**
        payment_authentication_callback_url (str): The URL consumer is redirected to
            if the bank requests SCA. This field is only needed if ConsumerPresent is
            true.
        payment_info (CheckoutPaymentInfo): The model property of type
            CheckoutPaymentInfo.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "test": "Test",
        "location_id": "LocationId",
        "send_email_receipt": "SendEmailReceipt",
        "sales_rep_id": "SalesRepId",
        "consumer_present": "ConsumerPresent",
        "payment_authentication_callback_url": "PaymentAuthenticationCallbackUrl",
        "payment_info": "PaymentInfo",
    }

    _optionals = [
        "test",
        "location_id",
        "send_email_receipt",
        "sales_rep_id",
        "consumer_present",
        "payment_authentication_callback_url",
        "payment_info",
    ]

    def __init__(
        self,
        client_id=None,
        test=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        send_email_receipt=APIHelper.SKIP,
        sales_rep_id=APIHelper.SKIP,
        consumer_present=APIHelper.SKIP,
        payment_authentication_callback_url=APIHelper.SKIP,
        payment_info=APIHelper.SKIP):
        """Initialize a PurchaseAccountCreditRequest instance."""
        # Initialize members of the class
        if test is not APIHelper.SKIP:
            self.test = test
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        self.client_id = client_id
        if send_email_receipt is not APIHelper.SKIP:
            self.send_email_receipt = send_email_receipt
        if sales_rep_id is not APIHelper.SKIP:
            self.sales_rep_id = sales_rep_id
        if consumer_present is not APIHelper.SKIP:
            self.consumer_present = consumer_present
        if payment_authentication_callback_url is not APIHelper.SKIP:
            self.payment_authentication_callback_url =\
                 payment_authentication_callback_url
        if payment_info is not APIHelper.SKIP:
            self.payment_info = payment_info

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        send_email_receipt =\
            dictionary.get("SendEmailReceipt")\
            if "SendEmailReceipt" in dictionary.keys()\
                else APIHelper.SKIP
        sales_rep_id =\
            dictionary.get("SalesRepId")\
            if dictionary.get("SalesRepId")\
                else APIHelper.SKIP
        consumer_present =\
            dictionary.get("ConsumerPresent")\
            if "ConsumerPresent" in dictionary.keys()\
                else APIHelper.SKIP
        payment_authentication_callback_url =\
            dictionary.get("PaymentAuthenticationCallbackUrl")\
            if dictionary.get("PaymentAuthenticationCallbackUrl")\
                else APIHelper.SKIP
        payment_info =\
            CheckoutPaymentInfo.from_dictionary(
                dictionary.get("PaymentInfo"))\
                if "PaymentInfo" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   test,
                   location_id,
                   send_email_receipt,
                   sales_rep_id,
                   consumer_present,
                   payment_authentication_callback_url,
                   payment_info)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _client_id=self.client_id
        _send_email_receipt=(
            self.send_email_receipt
            if hasattr(self, "send_email_receipt")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _payment_info=(
            self.payment_info
            if hasattr(self, "payment_info")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!r}, "
            f"location_id={_location_id!r}, "
            f"client_id={_client_id!r}, "
            f"send_email_receipt={_send_email_receipt!r}, "
            f"sales_rep_id={_sales_rep_id!r}, "
            f"consumer_present={_consumer_present!r}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!r}, "
            f"payment_info={_payment_info!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _client_id=self.client_id
        _send_email_receipt=(
            self.send_email_receipt
            if hasattr(self, "send_email_receipt")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _payment_info=(
            self.payment_info
            if hasattr(self, "payment_info")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!s}, "
            f"location_id={_location_id!s}, "
            f"client_id={_client_id!s}, "
            f"send_email_receipt={_send_email_receipt!s}, "
            f"sales_rep_id={_sales_rep_id!s}, "
            f"consumer_present={_consumer_present!s}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!s}, "
            f"payment_info={_payment_info!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ClientRewardTransaction(object):
    """Implementation of the 'ClientRewardTransaction' model.

    Contains information about the transaction details.

    Attributes:
        action_date_time (datetime): The date and time when the points were earned or
            redeemed in the site local time zone.
        action (Action10Enum): Indicates if rewards were earned or redeemed.
        source (str): The source of the reward transaction.
        source_id (int): The unique identifier in the MINDBODY system for the
            **Source**.
        expiration_date_time (datetime): The date and time when earned points expire.
            This is calculated based on site and client rewards settings. This date
            will be in the site local time zone and may be **null**.
        points (int): The amount of points the client earned or redeemed.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "action_date_time": "ActionDateTime",
        "action": "Action",
        "source": "Source",
        "source_id": "SourceID",
        "expiration_date_time": "ExpirationDateTime",
        "points": "Points",
    }

    _optionals = [
        "action_date_time",
        "action",
        "source",
        "source_id",
        "expiration_date_time",
        "points",
    ]

    def __init__(
        self,
        action_date_time=APIHelper.SKIP,
        action=APIHelper.SKIP,
        source=APIHelper.SKIP,
        source_id=APIHelper.SKIP,
        expiration_date_time=APIHelper.SKIP,
        points=APIHelper.SKIP):
        """Initialize a ClientRewardTransaction instance."""
        # Initialize members of the class
        if action_date_time is not APIHelper.SKIP:
            self.action_date_time =\
                 APIHelper.apply_datetime_converter(
                action_date_time, APIHelper.RFC3339DateTime)\
                 if action_date_time else None
        if action is not APIHelper.SKIP:
            self.action = action
        if source is not APIHelper.SKIP:
            self.source = source
        if source_id is not APIHelper.SKIP:
            self.source_id = source_id
        if expiration_date_time is not APIHelper.SKIP:
            self.expiration_date_time =\
                 APIHelper.apply_datetime_converter(
                expiration_date_time, APIHelper.RFC3339DateTime)\
                 if expiration_date_time else None
        if points is not APIHelper.SKIP:
            self.points = points

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        action_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ActionDateTime")).datetime\
            if dictionary.get("ActionDateTime") else APIHelper.SKIP
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else APIHelper.SKIP
        source =\
            dictionary.get("Source")\
            if dictionary.get("Source")\
                else APIHelper.SKIP
        source_id =\
            dictionary.get("SourceID")\
            if dictionary.get("SourceID")\
                else APIHelper.SKIP
        expiration_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ExpirationDateTime")).datetime\
            if dictionary.get("ExpirationDateTime") else APIHelper.SKIP
        points =\
            dictionary.get("Points")\
            if dictionary.get("Points")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(action_date_time,
                   action,
                   source,
                   source_id,
                   expiration_date_time,
                   points)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _action_date_time=(
            self.action_date_time
            if hasattr(self, "action_date_time")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _source=(
            self.source
            if hasattr(self, "source")
            else None
        )
        _source_id=(
            self.source_id
            if hasattr(self, "source_id")
            else None
        )
        _expiration_date_time=(
            self.expiration_date_time
            if hasattr(self, "expiration_date_time")
            else None
        )
        _points=(
            self.points
            if hasattr(self, "points")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"action_date_time={_action_date_time!r}, "
            f"action={_action!r}, "
            f"source={_source!r}, "
            f"source_id={_source_id!r}, "
            f"expiration_date_time={_expiration_date_time!r}, "
            f"points={_points!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _action_date_time=(
            self.action_date_time
            if hasattr(self, "action_date_time")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _source=(
            self.source
            if hasattr(self, "source")
            else None
        )
        _source_id=(
            self.source_id
            if hasattr(self, "source_id")
            else None
        )
        _expiration_date_time=(
            self.expiration_date_time
            if hasattr(self, "expiration_date_time")
            else None
        )
        _points=(
            self.points
            if hasattr(self, "points")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"action_date_time={_action_date_time!s}, "
            f"action={_action!s}, "
            f"source={_source!s}, "
            f"source_id={_source_id!s}, "
            f"expiration_date_time={_expiration_date_time!s}, "
            f"points={_points!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class BookingWindow(object):
    """Implementation of the 'BookingWindow' model.

    The booking window for registration

    Attributes:
        start_date_time (datetime): Date and time that the booking window opens; that
            is, the first day of sales.
        end_date_time (datetime): Date and time that the booking window closes; that
            is, the last day of sales.
        daily_start_time (datetime): The time that the booking window opens; that is,
            the time that the store opens.
        daily_end_time (datetime): The time that the booking window closes; that is,
            the time that the store closes.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "daily_start_time": "DailyStartTime",
        "daily_end_time": "DailyEndTime",
    }

    _optionals = [
        "start_date_time",
        "end_date_time",
        "daily_start_time",
        "daily_end_time",
    ]

    def __init__(
        self,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        daily_start_time=APIHelper.SKIP,
        daily_end_time=APIHelper.SKIP):
        """Initialize a BookingWindow instance."""
        # Initialize members of the class
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if daily_start_time is not APIHelper.SKIP:
            self.daily_start_time =\
                 APIHelper.apply_datetime_converter(
                daily_start_time, APIHelper.RFC3339DateTime)\
                 if daily_start_time else None
        if daily_end_time is not APIHelper.SKIP:
            self.daily_end_time =\
                 APIHelper.apply_datetime_converter(
                daily_end_time, APIHelper.RFC3339DateTime)\
                 if daily_end_time else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        daily_start_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("DailyStartTime")).datetime\
            if dictionary.get("DailyStartTime") else APIHelper.SKIP
        daily_end_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("DailyEndTime")).datetime\
            if dictionary.get("DailyEndTime") else APIHelper.SKIP

        # Return an object of this model
        return cls(start_date_time,
                   end_date_time,
                   daily_start_time,
                   daily_end_time)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _daily_start_time=(
            self.daily_start_time
            if hasattr(self, "daily_start_time")
            else None
        )
        _daily_end_time=(
            self.daily_end_time
            if hasattr(self, "daily_end_time")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"daily_start_time={_daily_start_time!r}, "
            f"daily_end_time={_daily_end_time!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _daily_start_time=(
            self.daily_start_time
            if hasattr(self, "daily_start_time")
            else None
        )
        _daily_end_time=(
            self.daily_end_time
            if hasattr(self, "daily_end_time")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"daily_start_time={_daily_start_time!s}, "
            f"daily_end_time={_daily_end_time!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ApiError(object):
    """Implementation of the 'ApiError' model.

    Attributes:
        message (str): The model property of type str.
        code (str): The model property of type str.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "message": "Message",
        "code": "Code",
    }

    _optionals = [
        "message",
        "code",
    ]

    def __init__(
        self,
        message=APIHelper.SKIP,
        code=APIHelper.SKIP):
        """Initialize a ApiError instance."""
        # Initialize members of the class
        if message is not APIHelper.SKIP:
            self.message = message
        if code is not APIHelper.SKIP:
            self.code = code

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        message =\
            dictionary.get("Message")\
            if dictionary.get("Message")\
                else APIHelper.SKIP
        code =\
            dictionary.get("Code")\
            if dictionary.get("Code")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(message,
                   code)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _message=(
            self.message
            if hasattr(self, "message")
            else None
        )
        _code=(
            self.code
            if hasattr(self, "code")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"message={_message!r}, "
            f"code={_code!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _message=(
            self.message
            if hasattr(self, "message")
            else None
        )
        _code=(
            self.code
            if hasattr(self, "code")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"message={_message!s}, "
            f"code={_code!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClassDescriptionsRequest(object):
    """Implementation of the 'GetClassDescriptionsRequest' model.

    Attributes:
        class_description_id (int): The ID of the requested client.
        program_ids (List[int]): A list of requested program IDs.
        start_class_date_time (datetime): Filters the results to class descriptions
            for scheduled classes that happen on or after the given date and time.
        end_class_date_time (datetime): Filters the results to class descriptions for
            scheduled classes that happen before the given date and time.
        staff_id (int): Filters results to class descriptions for scheduled classes
            taught by the given staff member.
        location_id (int): Filters results to classes descriptions for schedule
            classes as the given location.
        include_inactive (bool): Includes inactive class descriptions, defaulting to
            true. When set to false, it filters out inactive class descriptions.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_description_id": "ClassDescriptionId",
        "program_ids": "ProgramIds",
        "start_class_date_time": "StartClassDateTime",
        "end_class_date_time": "EndClassDateTime",
        "staff_id": "StaffId",
        "location_id": "LocationId",
        "include_inactive": "IncludeInactive",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "class_description_id",
        "program_ids",
        "start_class_date_time",
        "end_class_date_time",
        "staff_id",
        "location_id",
        "include_inactive",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        class_description_id=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        start_class_date_time=APIHelper.SKIP,
        end_class_date_time=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        include_inactive=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetClassDescriptionsRequest instance."""
        # Initialize members of the class
        if class_description_id is not APIHelper.SKIP:
            self.class_description_id = class_description_id
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if start_class_date_time is not APIHelper.SKIP:
            self.start_class_date_time =\
                 APIHelper.apply_datetime_converter(
                start_class_date_time, APIHelper.RFC3339DateTime)\
                 if start_class_date_time else None
        if end_class_date_time is not APIHelper.SKIP:
            self.end_class_date_time =\
                 APIHelper.apply_datetime_converter(
                end_class_date_time, APIHelper.RFC3339DateTime)\
                 if end_class_date_time else None
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if include_inactive is not APIHelper.SKIP:
            self.include_inactive = include_inactive
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_description_id =\
            dictionary.get("ClassDescriptionId")\
            if dictionary.get("ClassDescriptionId")\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        start_class_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartClassDateTime")).datetime\
            if dictionary.get("StartClassDateTime") else APIHelper.SKIP
        end_class_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndClassDateTime")).datetime\
            if dictionary.get("EndClassDateTime") else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        include_inactive =\
            dictionary.get("IncludeInactive")\
            if "IncludeInactive" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_description_id,
                   program_ids,
                   start_class_date_time,
                   end_class_date_time,
                   staff_id,
                   location_id,
                   include_inactive,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_description_id=(
            self.class_description_id
            if hasattr(self, "class_description_id")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _start_class_date_time=(
            self.start_class_date_time
            if hasattr(self, "start_class_date_time")
            else None
        )
        _end_class_date_time=(
            self.end_class_date_time
            if hasattr(self, "end_class_date_time")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_description_id={_class_description_id!r}, "
            f"program_ids={_program_ids!r}, "
            f"start_class_date_time={_start_class_date_time!r}, "
            f"end_class_date_time={_end_class_date_time!r}, "
            f"staff_id={_staff_id!r}, "
            f"location_id={_location_id!r}, "
            f"include_inactive={_include_inactive!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_description_id=(
            self.class_description_id
            if hasattr(self, "class_description_id")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _start_class_date_time=(
            self.start_class_date_time
            if hasattr(self, "start_class_date_time")
            else None
        )
        _end_class_date_time=(
            self.end_class_date_time
            if hasattr(self, "end_class_date_time")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_description_id={_class_description_id!s}, "
            f"program_ids={_program_ids!s}, "
            f"start_class_date_time={_start_class_date_time!s}, "
            f"end_class_date_time={_end_class_date_time!s}, "
            f"staff_id={_staff_id!s}, "
            f"location_id={_location_id!s}, "
            f"include_inactive={_include_inactive!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.location import (
    Location,
)
from mindbodypublicapi.models.program import (
    Program,
)


class ClientMembership(object):
    """Implementation of the 'ClientMembership' model.

    Attributes:
        restricted_locations (List[Location]): The locations that the membership is
            restricted to, if any.  Please note that client memberships with location
            restrictions can only be used to pay for scheduled services at the site
            to which they belong. Memberships with location restrictions can not be
            used to pay for scheduled services at other sites within an organization.
        icon_code (str): Text code that represents the `MembershipIcon`.
        membership_id (int): The membership's ID.
        active_date (datetime): The date that this pricing option became active and
            could be used to pay for services.
        count (int): The number of service sessions this pricing option contained
            when first purchased.
        current (bool): When `true`, there are service sessions remaining on the
            pricing option that can be used pay for the current session.<br />  When
            `false`, the client cannot use this pricing option to pay for other
            services.
        expiration_date (datetime): The date when the pricing option expires and can
            no longer be used to pay for services, even if unused service sessions
            remain on the option; expressed as UTC.
        id (int): The unique ID assigned to this pricing option, specific to when it
            was purchased by the client.
        product_id (int): The unique ID of this pricing option, not specific to any
            client's purchase of it.
        name (str): The name of this pricing option.
        payment_date (datetime): The date on which the client paid for this pricing
            option.
        program (Program): The model property of type Program.
        remaining (int): The number of service sessions remaining in the pricing
            option that can still be used.
        site_id (int): The ID of the subscriber site associated with this pricing
            option.
        action (Action1Enum): The action taken.
        client_id (str): The Client ID assigned to this pricing option, specific to
            when it was purchased by the client.
        returned (bool): Identification for purchased service is returned or not.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "restricted_locations": "RestrictedLocations",
        "icon_code": "IconCode",
        "membership_id": "MembershipId",
        "active_date": "ActiveDate",
        "count": "Count",
        "current": "Current",
        "expiration_date": "ExpirationDate",
        "id": "Id",
        "product_id": "ProductId",
        "name": "Name",
        "payment_date": "PaymentDate",
        "program": "Program",
        "remaining": "Remaining",
        "site_id": "SiteId",
        "action": "Action",
        "client_id": "ClientID",
        "returned": "Returned",
    }

    _optionals = [
        "restricted_locations",
        "icon_code",
        "membership_id",
        "active_date",
        "count",
        "current",
        "expiration_date",
        "id",
        "product_id",
        "name",
        "payment_date",
        "program",
        "remaining",
        "site_id",
        "action",
        "client_id",
        "returned",
    ]

    def __init__(
        self,
        restricted_locations=APIHelper.SKIP,
        icon_code=APIHelper.SKIP,
        membership_id=APIHelper.SKIP,
        active_date=APIHelper.SKIP,
        count=APIHelper.SKIP,
        current=APIHelper.SKIP,
        expiration_date=APIHelper.SKIP,
        id=APIHelper.SKIP,
        product_id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        payment_date=APIHelper.SKIP,
        program=APIHelper.SKIP,
        remaining=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        action=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        returned=APIHelper.SKIP):
        """Initialize a ClientMembership instance."""
        # Initialize members of the class
        if restricted_locations is not APIHelper.SKIP:
            self.restricted_locations = restricted_locations
        if icon_code is not APIHelper.SKIP:
            self.icon_code = icon_code
        if membership_id is not APIHelper.SKIP:
            self.membership_id = membership_id
        if active_date is not APIHelper.SKIP:
            self.active_date =\
                 APIHelper.apply_datetime_converter(
                active_date, APIHelper.RFC3339DateTime)\
                 if active_date else None
        if count is not APIHelper.SKIP:
            self.count = count
        if current is not APIHelper.SKIP:
            self.current = current
        if expiration_date is not APIHelper.SKIP:
            self.expiration_date =\
                 APIHelper.apply_datetime_converter(
                expiration_date, APIHelper.RFC3339DateTime)\
                 if expiration_date else None
        if id is not APIHelper.SKIP:
            self.id = id
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if name is not APIHelper.SKIP:
            self.name = name
        if payment_date is not APIHelper.SKIP:
            self.payment_date =\
                 APIHelper.apply_datetime_converter(
                payment_date, APIHelper.RFC3339DateTime)\
                 if payment_date else None
        if program is not APIHelper.SKIP:
            self.program = program
        if remaining is not APIHelper.SKIP:
            self.remaining = remaining
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if action is not APIHelper.SKIP:
            self.action = action
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if returned is not APIHelper.SKIP:
            self.returned = returned

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        restricted_locations = None
        if dictionary.get("RestrictedLocations") is not None:
            restricted_locations = [
                Location.from_dictionary(x)
                    for x in dictionary.get("RestrictedLocations")
            ]
        else:
            restricted_locations = APIHelper.SKIP
        icon_code =\
            dictionary.get("IconCode")\
            if dictionary.get("IconCode")\
                else APIHelper.SKIP
        membership_id =\
            dictionary.get("MembershipId")\
            if dictionary.get("MembershipId")\
                else APIHelper.SKIP
        active_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ActiveDate")).datetime\
            if dictionary.get("ActiveDate") else APIHelper.SKIP
        count =\
            dictionary.get("Count")\
            if dictionary.get("Count")\
                else APIHelper.SKIP
        current =\
            dictionary.get("Current")\
            if "Current" in dictionary.keys()\
                else APIHelper.SKIP
        expiration_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ExpirationDate")).datetime\
            if dictionary.get("ExpirationDate") else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        payment_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("PaymentDate")).datetime\
            if dictionary.get("PaymentDate") else APIHelper.SKIP
        program =\
            Program.from_dictionary(
                dictionary.get("Program"))\
                if "Program" in dictionary.keys()\
                else APIHelper.SKIP
        remaining =\
            dictionary.get("Remaining")\
            if dictionary.get("Remaining")\
                else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        action =\
            dictionary.get("Action")\
            if dictionary.get("Action")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientID")\
            if dictionary.get("ClientID")\
                else APIHelper.SKIP
        returned =\
            dictionary.get("Returned")\
            if "Returned" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(restricted_locations,
                   icon_code,
                   membership_id,
                   active_date,
                   count,
                   current,
                   expiration_date,
                   id,
                   product_id,
                   name,
                   payment_date,
                   program,
                   remaining,
                   site_id,
                   action,
                   client_id,
                   returned)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _restricted_locations=(
            self.restricted_locations
            if hasattr(self, "restricted_locations")
            else None
        )
        _icon_code=(
            self.icon_code
            if hasattr(self, "icon_code")
            else None
        )
        _membership_id=(
            self.membership_id
            if hasattr(self, "membership_id")
            else None
        )
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _current=(
            self.current
            if hasattr(self, "current")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _payment_date=(
            self.payment_date
            if hasattr(self, "payment_date")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _remaining=(
            self.remaining
            if hasattr(self, "remaining")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"restricted_locations={_restricted_locations!r}, "
            f"icon_code={_icon_code!r}, "
            f"membership_id={_membership_id!r}, "
            f"active_date={_active_date!r}, "
            f"count={_count!r}, "
            f"current={_current!r}, "
            f"expiration_date={_expiration_date!r}, "
            f"id={_id!r}, "
            f"product_id={_product_id!r}, "
            f"name={_name!r}, "
            f"payment_date={_payment_date!r}, "
            f"program={_program!r}, "
            f"remaining={_remaining!r}, "
            f"site_id={_site_id!r}, "
            f"action={_action!r}, "
            f"client_id={_client_id!r}, "
            f"returned={_returned!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _restricted_locations=(
            self.restricted_locations
            if hasattr(self, "restricted_locations")
            else None
        )
        _icon_code=(
            self.icon_code
            if hasattr(self, "icon_code")
            else None
        )
        _membership_id=(
            self.membership_id
            if hasattr(self, "membership_id")
            else None
        )
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _current=(
            self.current
            if hasattr(self, "current")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _payment_date=(
            self.payment_date
            if hasattr(self, "payment_date")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _remaining=(
            self.remaining
            if hasattr(self, "remaining")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _action=(
            self.action
            if hasattr(self, "action")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"restricted_locations={_restricted_locations!s}, "
            f"icon_code={_icon_code!s}, "
            f"membership_id={_membership_id!s}, "
            f"active_date={_active_date!s}, "
            f"count={_count!s}, "
            f"current={_current!s}, "
            f"expiration_date={_expiration_date!s}, "
            f"id={_id!s}, "
            f"product_id={_product_id!s}, "
            f"name={_name!s}, "
            f"payment_date={_payment_date!s}, "
            f"program={_program!s}, "
            f"remaining={_remaining!s}, "
            f"site_id={_site_id!s}, "
            f"action={_action!s}, "
            f"client_id={_client_id!s}, "
            f"returned={_returned!s}, "
            f")"
        )



# ruff: noqa: D104 | Missing docstring in public package
# ruff: noqa: RUF022 | `__all__` is not sorted
__all__ = [
    "appointment_controller",
    "base_controller",
    "class_controller",
    "client_controller",
    "cross_site_controller",
    "enrollment_controller",
    "payroll_controller",
    "pick_a_spot_controller",
    "pricing_option_controller",
    "sale_controller",
    "site_controller",
    "staff_controller",
    "user_token_controller",
]



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.booking_window import (
    BookingWindow,
)
from mindbodypublicapi.models.class_description import (
    ClassDescription,
)
from mindbodypublicapi.models.client import (
    Client,
)
from mindbodypublicapi.models.location import (
    Location,
)
from mindbodypublicapi.models.resource_slim import (
    ResourceSlim,
)
from mindbodypublicapi.models.staff import Staff
from mindbodypublicapi.models.visit import Visit


class Class(object):
    """Implementation of the 'Class' model.

    Represents a single class instance. The class meets at the start time, goes until
    the end time.

    Attributes:
        class_schedule_id (int): The ID used to retrieve the class schedule for the
            desired class.
        visits (List[Visit]): Contains information about visits.
        clients (List[Client]): Contains information about clients.
        location (Location): The model property of type Location.
        resource (ResourceSlim): Contains information about resources, such as rooms.
        max_capacity (int): The maximum number of clients allowed in the class.
        web_capacity (int): The maximum number of clients allowed to sign up online
            for the class.
        total_booked (int): The total number of clients booked in the class.
        total_signed_in (int): The total number of clients signed into the class.
        total_booked_waitlist (int): The total number of booked clients on the
            waiting list for the class.
        web_booked (int): The total number of clients who signed up online for the
            class.
        semester_id (int): The ID of the semester that the class is a part of, if any.
        is_canceled (bool): When `true`, indicates that the class has been
            cancelled.<br />  When `false`, indicates that the class has not been
            cancelled.
        substitute (bool): When `true`, indicates that the class is being taught by a
            substitute teacher.<br />  When `false`, indicates that the class is
            being taught by its regular teacher.
        active (bool): When `true`, indicates that the class is shown to clients when
            in consumer mode.<br />  When `false`, indicates that the class is not
            shown to clients when in consumer mode.
        is_waitlist_available (bool): When `true`, indicates that the clients can be
            placed on a waiting list for the class.<br />  When `false`, indicates
            that the clients cannot be placed on a waiting list for the class.
        is_enrolled (bool): When `true`, indicates that the client with the given
            `ClientId` is enrolled in this class.<br />  When `false`, indicates that
            the client with the given `ClientId` is not enrolled in this class.
        hide_cancel (bool): When `true`, indicates that this class is hidden when
            cancelled.<br />  When `false`, indicates that this class is not hidden
            when cancelled.
        id (int): The unique identifier for the class.
        is_available (bool): When `true`, indicates that the client with the given
            client ID can book this class.<br />  When `false`, indicates that the
            client with the given client ID cannot book this class.
        start_date_time (datetime): The time this class is scheduled to start.
        end_date_time (datetime): The time this class is scheduled to end.
        last_modified_date_time (datetime): The last time this class was modified.
        class_description (ClassDescription): Represents a class definition. The
            class meets at the start time, goes until the end time.
        staff (Staff): The Staff
        booking_window (BookingWindow): The booking window for registration
        booking_status (BookingStatusEnum): Contains the booking’s payment status.
        virtual_stream_link (str): The link to the Mindbody-hosted live stream for
            the class. This is `null` when no live stream is configured for the class.
        wait_list_size (int): The maximum number allowed on the waiting list for the
            class.
        class_notes (str): Notes for the class

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "class_schedule_id": "ClassScheduleId",
        "visits": "Visits",
        "clients": "Clients",
        "location": "Location",
        "resource": "Resource",
        "max_capacity": "MaxCapacity",
        "web_capacity": "WebCapacity",
        "total_booked": "TotalBooked",
        "total_signed_in": "TotalSignedIn",
        "total_booked_waitlist": "TotalBookedWaitlist",
        "web_booked": "WebBooked",
        "semester_id": "SemesterId",
        "is_canceled": "IsCanceled",
        "substitute": "Substitute",
        "active": "Active",
        "is_waitlist_available": "IsWaitlistAvailable",
        "is_enrolled": "IsEnrolled",
        "hide_cancel": "HideCancel",
        "id": "Id",
        "is_available": "IsAvailable",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "last_modified_date_time": "LastModifiedDateTime",
        "class_description": "ClassDescription",
        "staff": "Staff",
        "booking_window": "BookingWindow",
        "booking_status": "BookingStatus",
        "virtual_stream_link": "VirtualStreamLink",
        "wait_list_size": "WaitListSize",
        "class_notes": "ClassNotes",
    }

    _optionals = [
        "class_schedule_id",
        "visits",
        "clients",
        "location",
        "resource",
        "max_capacity",
        "web_capacity",
        "total_booked",
        "total_signed_in",
        "total_booked_waitlist",
        "web_booked",
        "semester_id",
        "is_canceled",
        "substitute",
        "active",
        "is_waitlist_available",
        "is_enrolled",
        "hide_cancel",
        "id",
        "is_available",
        "start_date_time",
        "end_date_time",
        "last_modified_date_time",
        "class_description",
        "staff",
        "booking_window",
        "booking_status",
        "virtual_stream_link",
        "wait_list_size",
        "class_notes",
    ]

    def __init__(
        self,
        class_schedule_id=APIHelper.SKIP,
        visits=APIHelper.SKIP,
        clients=APIHelper.SKIP,
        location=APIHelper.SKIP,
        resource=APIHelper.SKIP,
        max_capacity=APIHelper.SKIP,
        web_capacity=APIHelper.SKIP,
        total_booked=APIHelper.SKIP,
        total_signed_in=APIHelper.SKIP,
        total_booked_waitlist=APIHelper.SKIP,
        web_booked=APIHelper.SKIP,
        semester_id=APIHelper.SKIP,
        is_canceled=APIHelper.SKIP,
        substitute=APIHelper.SKIP,
        active=APIHelper.SKIP,
        is_waitlist_available=APIHelper.SKIP,
        is_enrolled=APIHelper.SKIP,
        hide_cancel=APIHelper.SKIP,
        id=APIHelper.SKIP,
        is_available=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        last_modified_date_time=APIHelper.SKIP,
        class_description=APIHelper.SKIP,
        staff=APIHelper.SKIP,
        booking_window=APIHelper.SKIP,
        booking_status=APIHelper.SKIP,
        virtual_stream_link=APIHelper.SKIP,
        wait_list_size=APIHelper.SKIP,
        class_notes=APIHelper.SKIP):
        """Initialize a Class instance."""
        # Initialize members of the class
        if class_schedule_id is not APIHelper.SKIP:
            self.class_schedule_id = class_schedule_id
        if visits is not APIHelper.SKIP:
            self.visits = visits
        if clients is not APIHelper.SKIP:
            self.clients = clients
        if location is not APIHelper.SKIP:
            self.location = location
        if resource is not APIHelper.SKIP:
            self.resource = resource
        if max_capacity is not APIHelper.SKIP:
            self.max_capacity = max_capacity
        if web_capacity is not APIHelper.SKIP:
            self.web_capacity = web_capacity
        if total_booked is not APIHelper.SKIP:
            self.total_booked = total_booked
        if total_signed_in is not APIHelper.SKIP:
            self.total_signed_in = total_signed_in
        if total_booked_waitlist is not APIHelper.SKIP:
            self.total_booked_waitlist = total_booked_waitlist
        if web_booked is not APIHelper.SKIP:
            self.web_booked = web_booked
        if semester_id is not APIHelper.SKIP:
            self.semester_id = semester_id
        if is_canceled is not APIHelper.SKIP:
            self.is_canceled = is_canceled
        if substitute is not APIHelper.SKIP:
            self.substitute = substitute
        if active is not APIHelper.SKIP:
            self.active = active
        if is_waitlist_available is not APIHelper.SKIP:
            self.is_waitlist_available = is_waitlist_available
        if is_enrolled is not APIHelper.SKIP:
            self.is_enrolled = is_enrolled
        if hide_cancel is not APIHelper.SKIP:
            self.hide_cancel = hide_cancel
        if id is not APIHelper.SKIP:
            self.id = id
        if is_available is not APIHelper.SKIP:
            self.is_available = is_available
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if last_modified_date_time is not APIHelper.SKIP:
            self.last_modified_date_time =\
                 APIHelper.apply_datetime_converter(
                last_modified_date_time, APIHelper.RFC3339DateTime)\
                 if last_modified_date_time else None
        if class_description is not APIHelper.SKIP:
            self.class_description = class_description
        if staff is not APIHelper.SKIP:
            self.staff = staff
        if booking_window is not APIHelper.SKIP:
            self.booking_window = booking_window
        if booking_status is not APIHelper.SKIP:
            self.booking_status = booking_status
        if virtual_stream_link is not APIHelper.SKIP:
            self.virtual_stream_link = virtual_stream_link
        if wait_list_size is not APIHelper.SKIP:
            self.wait_list_size = wait_list_size
        if class_notes is not APIHelper.SKIP:
            self.class_notes = class_notes

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        class_schedule_id =\
            dictionary.get("ClassScheduleId")\
            if dictionary.get("ClassScheduleId")\
                else APIHelper.SKIP
        visits = None
        if dictionary.get("Visits") is not None:
            visits = [
                Visit.from_dictionary(x)
                    for x in dictionary.get("Visits")
            ]
        else:
            visits = APIHelper.SKIP
        clients = None
        if dictionary.get("Clients") is not None:
            clients = [
                Client.from_dictionary(x)
                    for x in dictionary.get("Clients")
            ]
        else:
            clients = APIHelper.SKIP
        location =\
            Location.from_dictionary(
                dictionary.get("Location"))\
                if "Location" in dictionary.keys()\
                else APIHelper.SKIP
        resource =\
            ResourceSlim.from_dictionary(
                dictionary.get("Resource"))\
                if "Resource" in dictionary.keys()\
                else APIHelper.SKIP
        max_capacity =\
            dictionary.get("MaxCapacity")\
            if dictionary.get("MaxCapacity")\
                else APIHelper.SKIP
        web_capacity =\
            dictionary.get("WebCapacity")\
            if dictionary.get("WebCapacity")\
                else APIHelper.SKIP
        total_booked =\
            dictionary.get("TotalBooked")\
            if dictionary.get("TotalBooked")\
                else APIHelper.SKIP
        total_signed_in =\
            dictionary.get("TotalSignedIn")\
            if dictionary.get("TotalSignedIn")\
                else APIHelper.SKIP
        total_booked_waitlist =\
            dictionary.get("TotalBookedWaitlist")\
            if dictionary.get("TotalBookedWaitlist")\
                else APIHelper.SKIP
        web_booked =\
            dictionary.get("WebBooked")\
            if dictionary.get("WebBooked")\
                else APIHelper.SKIP
        semester_id =\
            dictionary.get("SemesterId")\
            if dictionary.get("SemesterId")\
                else APIHelper.SKIP
        is_canceled =\
            dictionary.get("IsCanceled")\
            if "IsCanceled" in dictionary.keys()\
                else APIHelper.SKIP
        substitute =\
            dictionary.get("Substitute")\
            if "Substitute" in dictionary.keys()\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        is_waitlist_available =\
            dictionary.get("IsWaitlistAvailable")\
            if "IsWaitlistAvailable" in dictionary.keys()\
                else APIHelper.SKIP
        is_enrolled =\
            dictionary.get("IsEnrolled")\
            if "IsEnrolled" in dictionary.keys()\
                else APIHelper.SKIP
        hide_cancel =\
            dictionary.get("HideCancel")\
            if "HideCancel" in dictionary.keys()\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        is_available =\
            dictionary.get("IsAvailable")\
            if "IsAvailable" in dictionary.keys()\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        last_modified_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDateTime")).datetime\
            if dictionary.get("LastModifiedDateTime") else APIHelper.SKIP
        class_description =\
            ClassDescription.from_dictionary(
                dictionary.get("ClassDescription"))\
                if "ClassDescription" in dictionary.keys()\
                else APIHelper.SKIP
        staff =\
            Staff.from_dictionary(
                dictionary.get("Staff"))\
                if "Staff" in dictionary.keys()\
                else APIHelper.SKIP
        booking_window =\
            BookingWindow.from_dictionary(
                dictionary.get("BookingWindow"))\
                if "BookingWindow" in dictionary.keys()\
                else APIHelper.SKIP
        booking_status =\
            dictionary.get("BookingStatus")\
            if dictionary.get("BookingStatus")\
                else APIHelper.SKIP
        virtual_stream_link =\
            dictionary.get("VirtualStreamLink")\
            if dictionary.get("VirtualStreamLink")\
                else APIHelper.SKIP
        wait_list_size =\
            dictionary.get("WaitListSize")\
            if dictionary.get("WaitListSize")\
                else APIHelper.SKIP
        class_notes =\
            dictionary.get("ClassNotes")\
            if dictionary.get("ClassNotes")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(class_schedule_id,
                   visits,
                   clients,
                   location,
                   resource,
                   max_capacity,
                   web_capacity,
                   total_booked,
                   total_signed_in,
                   total_booked_waitlist,
                   web_booked,
                   semester_id,
                   is_canceled,
                   substitute,
                   active,
                   is_waitlist_available,
                   is_enrolled,
                   hide_cancel,
                   id,
                   is_available,
                   start_date_time,
                   end_date_time,
                   last_modified_date_time,
                   class_description,
                   staff,
                   booking_window,
                   booking_status,
                   virtual_stream_link,
                   wait_list_size,
                   class_notes)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _class_schedule_id=(
            self.class_schedule_id
            if hasattr(self, "class_schedule_id")
            else None
        )
        _visits=(
            self.visits
            if hasattr(self, "visits")
            else None
        )
        _clients=(
            self.clients
            if hasattr(self, "clients")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _resource=(
            self.resource
            if hasattr(self, "resource")
            else None
        )
        _max_capacity=(
            self.max_capacity
            if hasattr(self, "max_capacity")
            else None
        )
        _web_capacity=(
            self.web_capacity
            if hasattr(self, "web_capacity")
            else None
        )
        _total_booked=(
            self.total_booked
            if hasattr(self, "total_booked")
            else None
        )
        _total_signed_in=(
            self.total_signed_in
            if hasattr(self, "total_signed_in")
            else None
        )
        _total_booked_waitlist=(
            self.total_booked_waitlist
            if hasattr(self, "total_booked_waitlist")
            else None
        )
        _web_booked=(
            self.web_booked
            if hasattr(self, "web_booked")
            else None
        )
        _semester_id=(
            self.semester_id
            if hasattr(self, "semester_id")
            else None
        )
        _is_canceled=(
            self.is_canceled
            if hasattr(self, "is_canceled")
            else None
        )
        _substitute=(
            self.substitute
            if hasattr(self, "substitute")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _is_waitlist_available=(
            self.is_waitlist_available
            if hasattr(self, "is_waitlist_available")
            else None
        )
        _is_enrolled=(
            self.is_enrolled
            if hasattr(self, "is_enrolled")
            else None
        )
        _hide_cancel=(
            self.hide_cancel
            if hasattr(self, "hide_cancel")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _is_available=(
            self.is_available
            if hasattr(self, "is_available")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _class_description=(
            self.class_description
            if hasattr(self, "class_description")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _booking_window=(
            self.booking_window
            if hasattr(self, "booking_window")
            else None
        )
        _booking_status=(
            self.booking_status
            if hasattr(self, "booking_status")
            else None
        )
        _virtual_stream_link=(
            self.virtual_stream_link
            if hasattr(self, "virtual_stream_link")
            else None
        )
        _wait_list_size=(
            self.wait_list_size
            if hasattr(self, "wait_list_size")
            else None
        )
        _class_notes=(
            self.class_notes
            if hasattr(self, "class_notes")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_schedule_id={_class_schedule_id!r}, "
            f"visits={_visits!r}, "
            f"clients={_clients!r}, "
            f"location={_location!r}, "
            f"resource={_resource!r}, "
            f"max_capacity={_max_capacity!r}, "
            f"web_capacity={_web_capacity!r}, "
            f"total_booked={_total_booked!r}, "
            f"total_signed_in={_total_signed_in!r}, "
            f"total_booked_waitlist={_total_booked_waitlist!r}, "
            f"web_booked={_web_booked!r}, "
            f"semester_id={_semester_id!r}, "
            f"is_canceled={_is_canceled!r}, "
            f"substitute={_substitute!r}, "
            f"active={_active!r}, "
            f"is_waitlist_available={_is_waitlist_available!r}, "
            f"is_enrolled={_is_enrolled!r}, "
            f"hide_cancel={_hide_cancel!r}, "
            f"id={_id!r}, "
            f"is_available={_is_available!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"last_modified_date_time={_last_modified_date_time!r}, "
            f"class_description={_class_description!r}, "
            f"staff={_staff!r}, "
            f"booking_window={_booking_window!r}, "
            f"booking_status={_booking_status!r}, "
            f"virtual_stream_link={_virtual_stream_link!r}, "
            f"wait_list_size={_wait_list_size!r}, "
            f"class_notes={_class_notes!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _class_schedule_id=(
            self.class_schedule_id
            if hasattr(self, "class_schedule_id")
            else None
        )
        _visits=(
            self.visits
            if hasattr(self, "visits")
            else None
        )
        _clients=(
            self.clients
            if hasattr(self, "clients")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _resource=(
            self.resource
            if hasattr(self, "resource")
            else None
        )
        _max_capacity=(
            self.max_capacity
            if hasattr(self, "max_capacity")
            else None
        )
        _web_capacity=(
            self.web_capacity
            if hasattr(self, "web_capacity")
            else None
        )
        _total_booked=(
            self.total_booked
            if hasattr(self, "total_booked")
            else None
        )
        _total_signed_in=(
            self.total_signed_in
            if hasattr(self, "total_signed_in")
            else None
        )
        _total_booked_waitlist=(
            self.total_booked_waitlist
            if hasattr(self, "total_booked_waitlist")
            else None
        )
        _web_booked=(
            self.web_booked
            if hasattr(self, "web_booked")
            else None
        )
        _semester_id=(
            self.semester_id
            if hasattr(self, "semester_id")
            else None
        )
        _is_canceled=(
            self.is_canceled
            if hasattr(self, "is_canceled")
            else None
        )
        _substitute=(
            self.substitute
            if hasattr(self, "substitute")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _is_waitlist_available=(
            self.is_waitlist_available
            if hasattr(self, "is_waitlist_available")
            else None
        )
        _is_enrolled=(
            self.is_enrolled
            if hasattr(self, "is_enrolled")
            else None
        )
        _hide_cancel=(
            self.hide_cancel
            if hasattr(self, "hide_cancel")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _is_available=(
            self.is_available
            if hasattr(self, "is_available")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _last_modified_date_time=(
            self.last_modified_date_time
            if hasattr(self, "last_modified_date_time")
            else None
        )
        _class_description=(
            self.class_description
            if hasattr(self, "class_description")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _booking_window=(
            self.booking_window
            if hasattr(self, "booking_window")
            else None
        )
        _booking_status=(
            self.booking_status
            if hasattr(self, "booking_status")
            else None
        )
        _virtual_stream_link=(
            self.virtual_stream_link
            if hasattr(self, "virtual_stream_link")
            else None
        )
        _wait_list_size=(
            self.wait_list_size
            if hasattr(self, "wait_list_size")
            else None
        )
        _class_notes=(
            self.class_notes
            if hasattr(self, "class_notes")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"class_schedule_id={_class_schedule_id!s}, "
            f"visits={_visits!s}, "
            f"clients={_clients!s}, "
            f"location={_location!s}, "
            f"resource={_resource!s}, "
            f"max_capacity={_max_capacity!s}, "
            f"web_capacity={_web_capacity!s}, "
            f"total_booked={_total_booked!s}, "
            f"total_signed_in={_total_signed_in!s}, "
            f"total_booked_waitlist={_total_booked_waitlist!s}, "
            f"web_booked={_web_booked!s}, "
            f"semester_id={_semester_id!s}, "
            f"is_canceled={_is_canceled!s}, "
            f"substitute={_substitute!s}, "
            f"active={_active!s}, "
            f"is_waitlist_available={_is_waitlist_available!s}, "
            f"is_enrolled={_is_enrolled!s}, "
            f"hide_cancel={_hide_cancel!s}, "
            f"id={_id!s}, "
            f"is_available={_is_available!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"last_modified_date_time={_last_modified_date_time!s}, "
            f"class_description={_class_description!s}, "
            f"staff={_staff!s}, "
            f"booking_window={_booking_window!s}, "
            f"booking_status={_booking_status!s}, "
            f"virtual_stream_link={_virtual_stream_link!s}, "
            f"wait_list_size={_wait_list_size!s}, "
            f"class_notes={_class_notes!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.get_commissions_response import (
    GetCommissionsResponse,
)
from mindbodypublicapi.models.get_scheduled_service_earnings_response import (
    GetScheduledServiceEarningsResponse,
)
from mindbodypublicapi.models.get_time_cards_response import (
    GetTimeCardsResponse,
)
from mindbodypublicapi.models.get_tips_response import (
    GetTipsResponse,
)


class PayrollController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize PayrollController object."""
        super(PayrollController, self).__init__(config)

    def get_commissions(self,
                        version,
                        site_id,
                        authorization=None,
                        request_end_date_time=None,
                        request_limit=None,
                        request_location_id=None,
                        request_offset=None,
                        request_staff_id=None,
                        request_start_date_time=None):
        """Perform a GET request to /public/v{version}/payroll/commissions.

        A staff authorization token is not required for this endpoint, but if one is
        passed, its permissions are honored. Depending on the access permissions
        configured for the staff member whose token is passed,
        the endpoint returns either only the payroll information for that staff
        member or it returns the payroll information for all staff members.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date_time (datetime, optional): The end of the date range for
                the payroll information to be returned. The maximum allowed date
                range is 14 days.<br />  Default: **Today’s date**  * If you do not
                supply an `EndDateTime`, the data returns for the period from the
                `StartDateTime` that you supply to today’s date.  * If you do not
                supply an `EndDateTime` or a `StartDateTime`, data returns for the
                seven days prior to today’s date.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_id (int, optional): A LocationId that you want to
                retrieve payroll information for. If you do not supply a
                `LocationId`, data from all locations is returned.
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_id (int, optional): A list of staff IDs that you want to
                retrieve payroll information for. If you do not supply a `StaffId`,
                all active staff members return, ordered by staff ID.
            request_start_date_time (datetime, optional): The beginning of the date
                range for the payroll information to be returned. The maximum allowed
                date range is 14 days.  * If you do not supply a `StartDateTime`,
                data returns for the seven days prior to the `EndDateTime` that you
                supply.  * If you do not supply either a `StartDateTime` or an
                `EndDateTime`, the data returns for seven days prior to today’s date.

        Returns:
            GetCommissionsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/payroll/commissions")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date_time)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationId")
                .value(request_location_id))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .query_param(Parameter()
                .key("request.startDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date_time)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetCommissionsResponse.from_dictionary),
        ).execute()

    def get_scheduled_service_earnings(self,
                                       version,
                                       site_id,
                                       authorization=None,
                                       request_end_date_time=None,
                                       request_limit=None,
                                       request_location_id=None,
                                       request_offset=None,
                                       request_scheduled_service_id=None,
                                       request_scheduled_service_type=None,
                                       request_staff_id=None,
                                       request_start_date_time=None):
        """Perform a GET request to
        /public/v{version}/payroll/scheduledserviceearnings.

        A staff authorization token is not required for this endpoint, but if one is
        passed, its permissions are honored. Depending on the access permissions
        configured for the staff member whose token is passed, the endpoint returns
        either only the payroll information for that staff member or it returns the
        payroll information for all staff members.
        Note that if a staff member is not paid for a class, earnings of zero are
        returned by this endpoint.
        Note that this endpoint calculates both bonus and no-reg rates for
        assistants.These rates are not supported by the Payroll report in the web
        interface.
        Note that this endpoint returns both the teacher’s adjusted rate and the
        assistant’s pay rate when the assistant is paid by the teacher.The Payroll
        report in the web interface only returns the teacher’s adjusted rate.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date_time (datetime, optional): The end of the date range for
                the payroll information to be returned. The maximum allowed date
                range is 14 days.<br />  Default: **Today’s date**  * If you do not
                supply an `EndDateTime`, the data returns for the period from the
                `StartDateTime` that you supply to today’s date.  * If you do not
                supply an `EndDateTime` or a `StartDateTime`, data returns for the
                seven days prior to today’s date.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_id (int, optional): A LocationId that you want to
                retrieve payroll information for. If you do not supply a
                `LocationId`, data from all locations is returned.
            request_offset (int, optional): Page offset, defaults to 0.
            request_scheduled_service_id (int, optional): Filters the results to a
                single scheduled service. This parameter must be used with a single
                ScheduledServiceType.
            request_scheduled_service_type (str, optional): Filters the results to
                schedule service earnings for specific types of services. Possible
                values:  * Class  * Appointment
            request_staff_id (int, optional): A list of staff IDs that you want to
                retrieve payroll information for. If you do not supply a `StaffId`,
                all active staff members return, ordered by staff ID.
            request_start_date_time (datetime, optional): The beginning of the date
                range for the payroll information to be returned. The maximum allowed
                date range is 14 days.  * If you do not supply a `StartDateTime`,
                data returns for the seven days prior to the `EndDateTime` that you
                supply.  * If you do not supply either a `StartDateTime` or an
                `EndDateTime`, the data returns for seven days prior to today’s date.

        Returns:
            GetScheduledServiceEarningsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/payroll/scheduledserviceearnings")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date_time)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationId")
                .value(request_location_id))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.scheduledServiceId")
                .value(request_scheduled_service_id))
            .query_param(Parameter()
                .key("request.scheduledServiceType")
                .value(request_scheduled_service_type))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .query_param(Parameter()
                .key("request.startDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date_time)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetScheduledServiceEarningsResponse.from_dictionary),
        ).execute()

    def get_time_cards(self,
                       version,
                       site_id,
                       authorization=None,
                       request_end_date_time=None,
                       request_limit=None,
                       request_location_id=None,
                       request_offset=None,
                       request_staff_id=None,
                       request_start_date_time=None):
        """Perform a GET request to /public/v{version}/payroll/timecards.

        This endpoint returns information for all locations. The **View reports for
        all locations permission **is not supported for staff auth tokens.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date_time (datetime, optional): The end of the date range for
                the payroll information to be returned. The maximum allowed date
                range is 14 days.<br />  Default: **Today’s date**  * If you do not
                supply an `EndDateTime`, the data returns for the period from the
                `StartDateTime` that you supply to today’s date.  * If you do not
                supply an `EndDateTime` or a `StartDateTime`, data returns for the
                seven days prior to today’s date.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_id (int, optional): A LocationId that you want to
                retrieve payroll information for. If you do not supply a
                `LocationId`, data from all locations is returned.
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_id (int, optional): A list of staff IDs that you want to
                retrieve payroll information for. If you do not supply a `StaffId`,
                all active staff members return, ordered by staff ID.
            request_start_date_time (datetime, optional): The beginning of the date
                range for the payroll information to be returned. The maximum allowed
                date range is 14 days.  * If you do not supply a `StartDateTime`,
                data returns for the seven days prior to the `EndDateTime` that you
                supply.  * If you do not supply either a `StartDateTime` or an
                `EndDateTime`, the data returns for seven days prior to today’s date.

        Returns:
            GetTimeCardsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/payroll/timecards")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date_time)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationId")
                .value(request_location_id))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .query_param(Parameter()
                .key("request.startDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date_time)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetTimeCardsResponse.from_dictionary),
        ).execute()

    def get_tips(self,
                 version,
                 site_id,
                 authorization=None,
                 request_end_date_time=None,
                 request_limit=None,
                 request_location_id=None,
                 request_offset=None,
                 request_staff_id=None,
                 request_start_date_time=None):
        """Perform a GET request to /public/v{version}/payroll/tips.

        A staff authorization token is not required for this endpoint, but if one is
        passed, its permissions are honored. Depending on the access permissions
        configured for the staff member whose token is passed,
        the endpoint returns either only the payroll information for that staff
        member or it returns the payroll information for all staff members.
        This endpoint returns information for all locations.The** View reports for
        all locations **permission is not supported for staff auth tokens.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date_time (datetime, optional): The end of the date range for
                the payroll information to be returned. The maximum allowed date
                range is 14 days.<br />  Default: **Today’s date**  * If you do not
                supply an `EndDateTime`, the data returns for the period from the
                `StartDateTime` that you supply to today’s date.  * If you do not
                supply an `EndDateTime` or a `StartDateTime`, data returns for the
                seven days prior to today’s date.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_id (int, optional): A LocationId that you want to
                retrieve payroll information for. If you do not supply a
                `LocationId`, data from all locations is returned.
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_id (int, optional): A list of staff IDs that you want to
                retrieve payroll information for. If you do not supply a `StaffId`,
                all active staff members return, ordered by staff ID.
            request_start_date_time (datetime, optional): The beginning of the date
                range for the payroll information to be returned. The maximum allowed
                date range is 14 days.  * If you do not supply a `StartDateTime`,
                data returns for the seven days prior to the `EndDateTime` that you
                supply.  * If you do not supply either a `StartDateTime` or an
                `EndDateTime`, the data returns for seven days prior to today’s date.

        Returns:
            GetTipsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/payroll/tips")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date_time)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationId")
                .value(request_location_id))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .query_param(Parameter()
                .key("request.startDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date_time)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetTipsResponse.from_dictionary),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class M0CultureNeutralPublicKeyTokenB77a5c561934e089(object):
    """Implementation of the
    '0, Culture=neutral, PublicKeyToken=b77a5c561934e089]]' model.

    Attributes:
        key (str): The model property of type str.
        value (List[str]): The model property of type List[str].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key": "key",
        "value": "value",
    }

    _optionals = [
        "key",
        "value",
    ]

    def __init__(
        self,
        key=APIHelper.SKIP,
        value=APIHelper.SKIP):
        """Initialize a M0CultureNeutralPublicKeyTokenB77a5c561934e089 instance."""
        # Initialize members of the class
        if key is not APIHelper.SKIP:
            self.key = key
        if value is not APIHelper.SKIP:
            self.value = value

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        key =\
            dictionary.get("key")\
            if dictionary.get("key")\
                else APIHelper.SKIP
        value =\
            dictionary.get("value")\
            if dictionary.get("value")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(key,
                   value)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _key=(
            self.key
            if hasattr(self, "key")
            else None
        )
        _value=(
            self.value
            if hasattr(self, "value")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"key={_key!r}, "
            f"value={_value!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _key=(
            self.key
            if hasattr(self, "key")
            else None
        )
        _value=(
            self.value
            if hasattr(self, "value")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"key={_key!s}, "
            f"value={_value!s}, "
            f")"
        )




"""
mindbodypublicapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from apimatic_core.http.response.http_response import HttpResponse as CoreHttpResponse


class HttpResponse(CoreHttpResponse):
    """
    Represent an HTTP response returned by the server.

    Stores response metadata such as status code, reason phrase, headers, and
     the raw response body, along with the originating request.

    Attributes:
        status_code (int): The HTTP status code returned by the server.
        reason_phrase (str): The reason phrase associated with the status code.
        headers (dict[str, str]): Response headers as key-value pairs.
        text (str): The raw response body as a string.
        request: The request object that resulted in this response.

    """

    def __init__(self,
                 status_code,
                 reason_phrase,
                 headers,
                 text,
                 request):
        """
        Initialize an HttpResponse instance.

        Args:
            status_code: The HTTP status code returned by the server.
            reason_phrase: The reason phrase associated with the status code.
            headers: Response headers as key-value pairs.
            text: The raw response body as a string.
            request: The request object that resulted in this response.

        """
        super().__init__(status_code, reason_phrase, headers, text, request)
